#gameNetwork
****


##overview
ランキングやアカウント機能を簡単に利用するためのサービス。
iOSは**Game Center**, Androidは**Google Game Play Service**を利用。
使い方詳細は[CoronaSDK Docks -game Network-](https://docs.coronalabs.com/plugin/gameNetwork-google/index.html)を参照

## 目次
**Android設定方法**

1. [Androidの設置](#how-to-android)
1. [build.setting](#build_setting)
1. [イベントについて](#event)
1. [sample code](#sample_code)
1. [機能一覧](#method)

**iOS設定方法**

1. [iOSの設置](#how-to-ios)
1. [build.setting](#build_setting-ios)
1. [イベントについて](#event)
1. [sample code](#sample_code)

-------

#<a name="how-to-android"></a>使用方法(Google Game Play Service)
1. Google PlayよりGame Play Game Serviceに登録する。[ここを参考](http://qiita.com/t2low/items/b447f6ed913fabd83b61)。ここではGoogle Play Store部分のみを作成（xml等は除く）
2. build.settingの変更。下記に記載しているコードを追加.
3. イベントの作成。下記にイベント作成については記載している
4. ランキングの形式を設定

### <a name="build_setting"></a>build.settingについて
```
settings =
{
    plugins =
    {
        ["CoronaProvider.gameNetwork.google"] =
        {
            publisherId = "com.coronalabs",
            supportedPlatforms = { android=true },
        },
    },
}
```

Google Playのアプリ名の下の数字を設定
![google play game app id](https://dl.pushbulletusercontent.com/RnJcr159yJcXmBctBj7xV93UpmBiKJSE/%E3%82%B9%E3%82%AF%E3%83%AA%E3%83%BC%E3%83%B3%E3%82%B7%E3%83%A7%E3%83%83%E3%83%88%202015-06-29%2014.45.44.png)

```
settings =
{
    android =
    {
        googlePlayGamesAppId = "123456789012",
    },
}
```

### <a name="event"></a>イベント作成



### <a name="method"></a>機能一覧

#####ランキング取得
```
gameNetwork.request("loadScore", {})
```

#####ログイン
```
gameNetwork.request( "login",{
    userInitiated = true,
    listener = requestCallback
})
```

-------
## 使用方法(Game Centerの場合)

1. build.settingの変更。下記に記載しているコードを追加.
1. ランキングの形式を設定

### <a name="build_setting"></a>build.settingについて
```
settings =
{
    plugins =
    {
        ["CoronaProvider.gameNetwork.apple"] =
        {
            publisherId = "com.coronalabs",
            supportedPlatforms = { iphone=true, ["iphone-sim"]=true },
        },
    },
}
```

## **達成項目・業績の設定**
---
1. iTunes ConnectまたはGoogle Play Developer Consoleで達成項目・業績（以下、称号）を設定する。
2. iOSでは称号設定の際に決めることの出来る達成項目ID、Androidは称号設定の際に自動生成されるID（画像で言う`Cgkl2p-l54EREAIQBQ`）を後述する方法でアプリ側に組み込む

### iOS
**達成項目**

1. 達成項目の参照名は開発者が見て分かる名前ならなんでも良い。
2. 達成項目IDは、リーダーボードと同じくユニークなIDになるようにする。`jp.co.freep.アプリ名.独自の命名規則`
3. 点数は全ての称号のうちこの称号が何点を占めるかを記載する。
4. 非表示にしたものはユーザーが達成するまで表示されず、`非表示`のステータスになる。
5. 複数回達成可能の項目は文字通り、その称号が複数回達成可能なのかを示す。複数回達成可能にすると条件を満たす度に称号が与えられる。

![スクリーンショット 2015-07-21 08.51.00.png](https://qiita-image-store.s3.amazonaws.com/0/36927/cabcaa7c-967f-b01b-6410-2cb2cf4d9da3.png "スクリーンショット 2015-07-21 08.51.00.png")

**達成項目のローカリゼーション**

1. 対象となる言語を設定する。海外対応ならその都度言語を設定し、ない場合はデフォルト言語が全てに適用される。
2. タイトルは称号名。「○○を達成しました」という形でユーザーに表示される。
3. 達成前に表示する説明は、称号取得前に表示する説明。前項で非表示に設定している場合はここに何を記載しても関係ない。
4. 達成後に取得する説明は、称号取得後にGamecenterで表示する説明。
5. 画像は512✕512で設定する。称号毎に画像を変えても良い。

![スクリーンショット 2015-07-21 09.08.49.png](https://qiita-image-store.s3.amazonaws.com/0/36927/9c692911-a641-c34e-172b-ef9c34a9ad6b.png "スクリーンショット 2015-07-21 09.08.49.png")



### Android

1. 名前は称号名。「業績○○を達成しました」という形でユーザーに表示される。
1. 達成後に取得する説明は、称号取得後にPlayゲームで表示する説明。
1. 画像は512✕512で設定する。称号毎に画像を変えても良い。
1. 初期状態で非表示にするとユーザーが達成するまで表示されず、`非表示`のステータスになる。
1. ポイントは全ての称号のうちこの称号が何点を占めるかを記載する。
1. リスト順はデフォルトで表示する称号の並び

![スクリーンショット 2015-07-21 08.44.35.png](https://qiita-image-store.s3.amazonaws.com/0/36927/d02be43c-9d38-b68f-249f-8a99bf5b12ee.png "スクリーンショット 2015-07-21 08.44.35.png")

### 称号の表示
リーダーボードと同じようにして使う。

```
#!lua
gamecenter.showAchievements()

```

### 称号データの取得
eventの中身にデータが入っている。

```
#!lua

local function eventHandler( event )
    data = event
end

gamecenter:addEventListener( eventHandler )
gamecenter.getAchievements()

```

### 称号の取得（開放）
ハイスコア達成・キャラ開放など任意のタイミングでこの関数を呼ぶことで、称号が取得（開放）できる。

```
#!lua

-- identifierはストアで称号設定の際に発行するID（jp.co.freep.hoge.degree1 or XXXXX-YYYYYYYY）
gamecenter.setAchievements( identifier )
```